Module django_couch
===================

Database access helper
----------------------
.. autofunction:: django_couch.db


All docs helper (iterator)
--------------------------
.. autofunction:: django_couch.all_docs

Generic view iterator helper
----------------------------
.. autofunction:: django_couch.view_iterator




Document bulk update helper
---------------------------
.. autoclass:: django_couch.Updater
   :members:

